                                                /*  USTUB.H  */

/* header and dummy global references for main.c stub in  */
/* standalone versions of hetro, lpanal, pvanal, sndinfo  */

OPARMS O, O_;                              /* dummy global resolving */
GLOBALS cglob, cglob_;                     /*  for references unused */

void fdrecord(FDCH *fdchp) {}
void initerror(char *s) {}
void perferror(char *s) {}
void sndwrterr(int n, int nput) {}

int  Graphable_(void);           /* initialise windows.  Returns 1 if X ok */
void MakeGraph_(WINDAT *, char *);       /* create wdw for a graph */
void MakeXYin_(XYINDAT *, MYFLT, MYFLT);
                                /* create a mouse input window; init scale */
void DrawGraph_(WINDAT *);       /* update graph in existing window */
void ReadXYin_(XYINDAT *);       /* fetch latest value from ms input wdw */
void KillGraph_(WINDAT *);       /* remove a graph window */
void KillXYin_(XYINDAT *);       /* remove a ms input window */
int  ExitGraph_(void); /* print click-Exit message in most recently active window */
